<h1 align="center" style="margin-top:20px; margin-bottom:50px;">

<a href="https://github.com/seixasgroup/oncapintada" target="_blank" rel="noopener noreferrer">
  <picture>
    <source srcset="https://raw.githubusercontent.com/seixasgroup/oncapintada/refs/heads/main/logo/logo_dark.png" media="(prefers-color-scheme: dark)">
    <source srcset="https://raw.githubusercontent.com/seixasgroup/oncapintada/refs/heads/main/logo/logo_light.png" media="(prefers-color-scheme: light)">
    <img src="https://raw.githubusercontent.com/seixasgroup/oncapintada/refs/heads/main/logo/logo_light.png" alt="Onça-pintada logo" style="height: auto; width: auto; max-height: 200px;">
  </picture>
</a>
</h1> 

[![License: MIT](https://img.shields.io/github/license/seixasgroup/oncapintada?color=green&style=for-the-badge)](LICENSE)    [![PyPI](https://img.shields.io/pypi/v/oncapintada?color=red&style=for-the-badge)](https://pypi.org/project/oncapintada/)

# Onça-pintada
<!-- (pronounced as OHN-sah peen-TAH-dah) -->
Onça-pintada is a toolkit to simulate and analyze alloys from first-principles methods.

# Installation

## From Pip
The easiest way to install Onça-pintada is with pip:

```python
pip install oncapintada
```

# Getting started

# License

This is an open source code under [MIT License](LICENSE).

